# -*- coding: utf-8 -*-
# @package Download Image Sentinel
"""
Install:

        $ pip install sentinelsat

Example:

        $ python -m doctest -v APISentinel-py
"""

import os
from sentinelsat.sentinel import SentinelAPI
from datetime import date
class APISentinel(object):
    """ Class for Sentinel satellites configuration
    Test Case
    >>> sentinel = APISentinel('asalazarg',  'geo135asg')
    >>> dir="../../../Documentos/Image_Sentinel"
    >>> products = sentinel.getProducts("POLYGON((-89.99450683593753 21.279137394108716,-89.13757324218751 21.2996106049456,-89.30236816406251 20.68418377935238,-90.0494384765625 20.715015145512098,-89.99450683593753 21.279137394108716))", ('20151219', date(2015,12,29)), {"platformname":"Sentinel-1"})
    >>> print len(products)
    3
    >>> sentinel.downloadProducts(products,dir)

     """

    def __init__(self,usernam,passw):
        """The constructor Initialize Sentinel Data.

        Args:
            self: The object pointer.
            usernam (str): Username, access credentials to https://scihub.copernicus.eu/dhus/#/home.
            passw (str): Password, access credentials to https://scihub.copernicus.eu/dhus/#/home.

        Returns:
            pointer: The object pointer.
        """
        self.username = usernam
        self.password = passw
        self.URL_Sentinel = 'https://scihub.copernicus.eu/dhus'

        # self.plot_width = 7
        # self.plot_height = 7
        # self.intersection_th = 30
        self.api = SentinelAPI(self.username, self.password, self.URL_Sentinel)

    def getProducts(self, area, date, searchParameters):
        """Gets products list Sentinel

        Args:
            self (pointer): The object pointer.
            area (str): Polygon WKT to find images.
                        Example:
                            args.footprint = geojson_to_wkt(read_geojson(path_json))
            date (str): Initial date and end date.
            searchParameters (str): Type platform Sentinel-1 or Sentinel-2
            Other Parameters: Additional keywords can be used to specify other query parameters, e.g. relativeorbitnum-
            ber=70. See https://scihub.copernicus.eu/twiki/do/view/SciHubUserGuide/3FullTextSearch for a full list. Ran-
            ge values can be passed as two-element tuples, e.g. cloudcoverpercentage=(0, 30). The time interval formats
            accepted by the ``date`` parameter can also be used with any other parameters that  expect time intervals
            (that is:'beginposition', 'endposition',

        Returns:
            OrderdDict: Product list Sentinel found.
        """
        products_list = self.api.query(area, date, **searchParameters)
        return products_list

    def downloadProducts(self,products,dir):
        """Download product(s) list Sentinel

        Args:
            self (pointer): The object pointer.
            products (str): Product(s) list Sentinel found.
            dir (str): Local path to save download files.

        Returns:
            Save Sentinel files.
        """
        os.chdir(dir)
        self.api.download_all(products)
